class nrCarrierConfig:
    def __init__(
        self, NCellId=1, SubcarrierSpacing=15, CyclicPrefix="normal", NSizeGrid=52, NStartGrid=0, NSlot=0, NFrame=0
    ):
        self.NCellId = NCellId
        self.SubcarrierSpacing = SubcarrierSpacing
        self.NSizeGrid = NSizeGrid
        self.NStartGrid = NStartGrid
        self.NSlot = NSlot
        self.NFrame = NFrame
